@@ -26,16 +26,20 @@ class BTInterface(AbstractInterface):
     'value': 0
     }
     self.interfaces = {'BlueZAdapter': ['org.bluez', self.bt_adapter_path, self.bt_adapter_iface, '']}
-    self.connected_device = None
+    self.connected_device = set()
 
   def process_signal_connected(self, prop, value, **kwargs):
     if str(prop) == 'Connected':
+      device = kwargs['path'].replace('%s/' % self.bt_adapter_path, '')
       if value:
-        self.connected_device = kwargs['path'].replace('%s/' % self.bt_adapter_path, '')
+        self.connected_device.add(device)
         return 2
       else:
-        self.connected_device = ''
-        return 1
+        self.connected_device.remove(device)
+        if len(self.connected_device) == 0:
+          return 1
+        else:
+          return None
     else:
       return None
 
@@ -53,8 +57,8 @@ class BTInterface(AbstractInterface):
     gobject.idle_add(self.run_commands, True)
 
   def turn_off(self):
-    if self.connected_device:
-      conndev_iface = dbus.Interface(self.get_bus().get_object('org.bluez', '%s/%s' % (self.bt_adapter_path, self.connected_device)), self.bt_device_iface)
+    for device in self.connected_device:
+      conndev_iface = dbus.Interface(self.get_bus().get_object('org.bluez', '%s/%s' % (self.bt_adapter_path, device)), self.bt_device_iface)
       conndev_iface.Disconnect()
     gobject.idle_add(self.run_commands, False)
 
